#!/usr/bin/python3 -I lib/

from fastkml import kml
from fastkml import geometry
import datetime
import sys

# Step-size for LineStrings, 5 minute entries
step6h=(6*60)/5
step12h=(12*60)/5
step24h=(12*60)/5

# Granularity for LineString entries
stepSize=step12h

if len(sys.argv) < 2:
    print('Error, need input KML file.')
    sys.exit(1)
else:
    f = open(sys.argv[1], 'r')

# Init KML object
k = kml.KML()

# Read input file contents and parse it
k.from_string(f.read().encode('utf-8'))

# Get the features so we can extract data
features = list(k.features())
f2 = list(features[0].features())

# Loop over the Placemarks, skip any LineStrings for now... :)
for entry in f2:

    # Grab the main date for the placemark
    # FIXME: Just blindly assume we have the timestamp from the prior entry if this is a placemark with only coords...
    if entry.name != None:
        placemarkTime = datetime.datetime.strptime(str(entry.name), '%Y-%m-%d %H:%M:%S %z')
    

    # Does the Placemark even have geometry?
    if hasattr(entry, "geometry"):
        if isinstance(entry.geometry, geometry.LineString):
            # Deal with entries in LineString
            index = 0
            for point in entry.geometry.coords:
                index = index + 1
                # If this is a entry to save?
                if index % stepSize == 0:
                    cTime = placemarkTime + datetime.timedelta(minutes=(index*5))
                    print('%s;%s;%s' % (cTime.isoformat(), point[0], point[1]))
        else:
            print('%s;%s;%s' % (placemarkTime.isoformat(), entry.geometry.x, entry.geometry.y))
